package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````R!8``#0```"TE0````0`!30`(``'
M`"@`'``;``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````Z(\`
M`.B/```%```````!``$```#HCP``Z(\!`.B/`0"X`@``'`,```8```````$`
M`@```/2/``#TCP$`](\!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&0$B@``!(H```2*```$`0``!`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$````RIH[!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-FAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````R!8````````#``L``````/"/`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#``"4
M(0``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``*"2`0``````$``5
M`#@``````````````!(```"9`P``8"P``!@````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,``%@W``!<
M````$@`+`(H``````````````!(```#(`P``!),!```````0`!4`3P``````
M````````$@```,`#``"@D@$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``!),!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#```4)```)````!(`"P#@`P``
M."0``%`````2``L`[`,``-0M``#<!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0```),!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``:$,```0!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``)R2`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``!),!```````0`!4`^@(`````````
M````$@```,\!`````````````!(```!'!```R!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$```$DP$``````!``%0`6!```B"0``#@%```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``&Q$``!``0``$@`+`$$"`````````````!(````M!```H)(!````
M```0`!4`.00``,`@``!<````$@`+`$$$``!\1@``L`(``!(`"P!(`@``````
M```````2````1@0``,@6````````$@`+`$\"`````````````!(```!.!```
MG"$``'@"```2``L`6P0``'@L``!<`0``$@`+`%8"`````````````!(```!M
M!```P"D``)0````2``L`7P(`````````````$@```'`"`````````````!(`
M``#C`@`````````````2````=P(`````````````$@```'L$``!4*@``9```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``#$
MD@$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```#$,``%P````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``6)(!``0````1`!0`C`0``+`T``"H`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS
M;RXQ`'!T:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-FAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``.B/`0`7````[(\!`!<```#\D0$`%P````R2`0`7````')(!`!<`
M```HD@$`%P```#"2`0`7````0)(!`!<```!(D@$`%P```%"2`0`7````5)(!
M`!<```!8D@$`%P```%R2`0`7````;)(!`!<```!PD@$`%P```'B2`0`7````
M?)(!`!<```"`D@$`%P```(22`0`7````B)(!`!<```"0D@$`%P```)22`0`7
M````G)(!`!<`````D@$`%0<```B2`0`5%```$)(!`!4B```4D@$`$2<``!B2
M`0`2)P``))(!`!4R```LD@$`%38``#22`0`5/```.)(!`!5"```\D@$`%4<`
M`$22`0`55@``3)(!`!5F``#PD`$`%@,``/20`0`6!```^)`!`!8%``#\D`$`
M%@<```"1`0`6"```!)$!`!8)```(D0$`%@H```R1`0`6#```$)$!`!8.```4
MD0$`%@\``!B1`0`6$```')$!`!82```@D0$`%A8``"21`0`6%P``*)$!`!88
M```LD0$`%AD``#"1`0`6&@``-)$!`!8;```XD0$`%AT``#R1`0`6'@``0)$!
M`!8?``!$D0$`%B```$B1`0`6(0``3)$!`!8C``!0D0$`%B@``%21`0`6*0``
M6)$!`!8J``!<D0$`%BP``&"1`0`6+0``9)$!`!8N``!HD0$`%B\``&R1`0`6
M,```<)$!`!8S``!TD0$`%C0``'B1`0`6-0``?)$!`!8W``"`D0$`%CD``(21
M`0`6.@``B)$!`!8[``",D0$`%CX``)"1`0`6/P``E)$!`!9!``"8D0$`%D(`
M`)R1`0`60P``H)$!`!9$``"DD0$`%D<``*B1`0`62```K)$!`!9)``"PD0$`
M%DL``+21`0`63P``N)$!`!91``"\D0$`%E0``,"1`0`65P``Q)$!`!98``#(
MD0$`%ED``,R1`0`66P``T)$!`!9<``#4D0$`%ET``-B1`0`67@``W)$!`!9?
M``#@D0$`%F$``.21`0`68@``Z)$!`!9C``#LD0$`%F4``/"1`0`6:0``])$!
M`!9J``#XD0$`%FL```3@+>4$X)_E#N"/X`CPON5$?0$``,:/XA?*C.)$_;SE
M`,:/XA?*C.(\_;SE`,:/XA?*C.(T_;SE`,:/XA?*C.(L_;SE`,:/XA?*C.(D
M_;SE`,:/XA?*C.(<_;SE`,:/XA?*C.(4_;SE`,:/XA?*C.(,_;SE`,:/XA?*
MC.($_;SE`,:/XA?*C.+\_+SE`,:/XA?*C.+T_+SE`,:/XA?*C.+L_+SE`,:/
MXA?*C.+D_+SE`,:/XA?*C.+<_+SE`,:/XA?*C.+4_+SE`,:/XA?*C.+,_+SE
M`,:/XA?*C.+$_+SE`,:/XA?*C.*\_+SE`,:/XA?*C.*T_+SE`,:/XA?*C.*L
M_+SE`,:/XA?*C.*D_+SE`,:/XA?*C.*<_+SE`,:/XA?*C.*4_+SE`,:/XA?*
MC.*,_+SE`,:/XA?*C.*$_+SE`,:/XA?*C.)\_+SE`,:/XA?*C.)T_+SE`,:/
MXA?*C.)L_+SE`,:/XA?*C.)D_+SE`,:/XA?*C.)<_+SE`,:/XA?*C.)4_+SE
M`,:/XA?*C.),_+SE`,:/XA?*C.)$_+SE`,:/XA?*C.(\_+SE`,:/XA?*C.(T
M_+SE`,:/XA?*C.(L_+SE`,:/XA?*C.(D_+SE`,:/XA?*C.(<_+SE`,:/XA?*
MC.(4_+SE`,:/XA?*C.(,_+SE`,:/XA?*C.($_+SE`,:/XA?*C.+\^[SE`,:/
MXA?*C.+T^[SE`,:/XA?*C.+L^[SE`,:/XA?*C.+D^[SE`,:/XA?*C.+<^[SE
M`,:/XA?*C.+4^[SE`,:/XA?*C.+,^[SE`,:/XA?*C.+$^[SE`,:/XA?*C.*\
M^[SE`,:/XA?*C.*T^[SE`,:/XA?*C.*L^[SE`,:/XA?*C.*D^[SE`,:/XA?*
MC.*<^[SE`,:/XA?*C.*4^[SE`,:/XA?*C.*,^[SE`,:/XA?*C.*$^[SE`,:/
MXA?*C.)\^[SE`,:/XA?*C.)T^[SE`,:/XA?*C.)L^[SE`,:/XA?*C.)D^[SE
M`,:/XA?*C.)<^[SE`,:/XA?*C.)4^[SE`,:/XA?*C.),^[SE`,:/XA?*C.)$
M^[SE`,:/XA?*C.(\^[SE`,:/XA?*C.(T^[SE`!"@X0(`H.$'T,WC-```ZD@@
MG^5($)_E`B"/X$0`G^4!,)+G``"/X`,`4.$>_R\A<$`MZ0!`H.,`4*#A`6!#
MX@!@1N`F8:#A!#"5Y#/_+^$&`%3A`4"$XOK__QIP@+WH_'D!`!@!``#X>`$`
M\$$MZ6`PG^5@$)_E8""?Y0,PC^`!4)/G`G"3YP<`5>'P@;TH`7!'X@5P1^``
M0*#C"%"%XJ=QH.$'``#J"&`5Y0A0A>(`,);E,_\OX0<`5.$``(;E`4"$XO"!
MO0@$,%7EH`!3X_3__PHG___KF'D!`#P!```@`0``@$`MZ6R!G^4`4%'B"("/
MX`C03>)+```*7"&?Y5PQG^4"()CG`%""Y0-@F.<(()7E`#"5Y0`@AN4`()/E
M``!2XSH```HX$9_E`1"8YP`@@>4`()/E`##2Y0``4^,%```*`2""XB\`4^,`
M(($%`3#2Y```4^/Z__\:``!0XP````KW_O_KDO__Z_@PG^4#,)CG``!3XS4`
M``KL,)_E['"?Y0.0F.<'<(_@"0!7X0&023('D$DP`$"@,RF1H#$$```J!#"7
MY#/_+^$)`%3A`4"$XOK__QJX`)_EN'"?Y0``C^#?_O_KL#"?Y0=PC^`#@)CG
M"`!7X0&`2#('@$@P`$"@,RB!H#$$```J!#"7Y#/_+^$$`%CA`4"$XOK__QH`
M();E`!"5Y00`E>5H"P#KL?[_ZTPPG^5D()_E`S"8YP(@C^``((/ER___ZA/`
MH.-0,)_E`B"@XP0`H.,`$*#C`S"/X`#`C>7Z_O_K`0"@X]?^_^N$___KQ___
MZB1Y`0!D`0``.`$``&P!``!<`0``*`$``)!W`0!(_O__3'<!`$0!``#0>0$`
M'#```,PPG^7P1RWI`)!0X@,PC^`K```*O""?Y0(PD^<`@)/E``!8XR@```H`
M4-GE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"8Y0``5.,,```*"&"@X00`
MH.$%(*#A"1"@X9+^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___
M&@0`H.'PA[WH"5"@X0$P]>4``%/C/0!3$_O__QH)4$7@YO__Z@A@1N`!4(7B
M1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__Z@A`H.'K___J?'<!`#@!``#P
M0RWI7"&?Y5PQG^4"((_@`S"2YZ303>(`4%#B`#"3Y9PPC>4`,*#C`@``"@`P
MU>4``%/C"@``&C`AG^4H,9_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C00``
M&J30C>+P@[WHEO[_ZP!`4.+Q__\*#7"@X?B`G^4(@(_@!`"@X0'__^L``%#C
M)P``"@TPT.4-8(#B+@!3XP(``!H!,-;E``!3X_3__PH-,-#E+@!3XR(```H%
M`*#AY_[_ZP"0H.$&`*#AY/[_ZP``B>`"`(#BY_[_ZP8PH.$`8*#A!2"@X0@0
MH.'3_O_K!Q"@X08`H.%2_O_K`0!PXP8`H.$#```*"#"=Y0\Z`^(!"5/C$@``
M"D'^_^L&`*#A-O[_ZP0`H.'9_O_K``!0X]?__QH$`*#A7?[_ZP4`H.$9_O_K
MO?__Z@$PUN4N`%/CV?__&@(PUN4``%/CR/__"M7__^JG___KZ___ZD3^_^N@
M=@$`0`$``&QV`0#(+@``$$`MZ8P@G^6,,)_E`B"/X*#03>(#,)+G#1"@X0`P
MD^6<,(WE`#"@XP!`H.$?_O_K``!0XP``H!,$```:"#"=Y0\Z`^(*"E/C`0E3
M$PH```I(()_E0#"?Y0(@C^`#,)+G`""3Y9PPG>4"(#/@`#"@XP<``!J@T(WB
M$("]Z`(0H.,$`*#A;/[_ZQ`/;^&@`J#A[O__ZAK^_^LH=0$`0`$``-QT`0`0
M0"WI],"?Y?0PG^4!VTWB"-!-X@S`C^`#,)SG!$"-X@`0H.$!*Z#C!`"@X0`P
MD^4$-(WE`#"@X]7]_^L!`$#B!`!0X0<``)H`(*#C`@``Z@0`4.$!(,#E`@``
M"@$P4.0O`%/C^?__"B\0H.,$`*#AUOW_ZP``4.,0```*!`!0X0`PH(,`,,"%
M!`"@X5#^_^MP()_E:#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XQ$``!H!
MVXWB"-"-XA"`O>A$()_E.#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XP4`
M`!HD`)_E``"/X`';C>((T(WB$$"]Z#7^_^K7_?_K?'0!`$`!``#X<P$`R',!
M``PL``#P0"WI`&"@X?@`G^7X,)_E``"/X`';3>(#,)#G#-!-XN@`G^4$<(WB
M`5"@X>`@G^4'$*#A``"/X``PD^4$-(WE`#"@X\_]_^L`P%#B%P``V@%`3.(!
M.X3B"#"#X@,PC>`$-%/E``!3XR,``!H``%3C#@``"@0@H.$O$*#C!P"@X07^
M_^L``%#C"```"H0`G^4``(_@)_[_ZP0PH.$'(*#A!A"@X0``D.4'_O_K!@``
MZF0`G^4``(_@'O[_ZP4@H.$&$*#A``"0Y:+]_^M,()_E-#"?Y0(@C^`#,)+G
M`""3Y00TG>4"(#/@`#"@XP0``!H!VXWB#-"-XO"`O>@,0*#AV___ZI#]_^ML
M<P$`0`$``.0K``#_`P``''0!`/AS`0"H<@$`\$<MZ0%`H.$4(I_E%#*?Y0(@
MC^`#,)+G"-!-X@`PD^4$,(WE`#"@XP`PT>4`4*#A/0!3XP%`@0($`*#A\?W_
MZPT0H.$`8*#A!0"@X9_^_^O4<9_E`)!0X@=PC^!!```*Z/W_ZP``5N$X``":
MO#&?Y0"`G>4#<)?G"(&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!
M(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"7Y=C]_^L``%#C"`"&YQ8`
M``H%`*#A`#"7Y0`@G>4"$9/G`3#0Y```4^,]`%,3`##!Y08```H!(('B`3#0
MY`(0H.$``%/C/0!3$P$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4Y```4^,!,.+E
M^___&@@AG^7X,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C-0``&@C0C>+P
MA[WH`9!)X@$PU.0``%/C`3#IY?O__QKN___JP#"?Y0-PE^<`@)?E`#"8Y0``
M4^,D```*"#"@X00@L^4)$*#A``!2XP&0B>+Z__\:`Q"!X@$1H.&0,)_E`S"/
MX``@D^4``%+C#P``&@$@H.,!`*#A`""#Y9;]_^L`H%#BU?__"@@0H.$)@:#A
M"""@X=;\_^L`H(?E`""@XP$PB>(#(8KG`)"-Y:'__^H(`*#AR_S_ZP``4.,`
MH*#A``"'Y<7__PH)@:#A\O__Z@.0H.$($*#CW___Z@#]_^M(<@$`0`$```!R
M`0`X`0``+'$!`,!R`0!P0"WI/""?Y3P`G^4\,)_E`B"/X```C^`#8)+G;?W_
MZRQ0G^4L0)_E!5"/X`1`C^`%,*#A!B"@X000H.%P0+WH``"0Y1C]_^H,<`$`
M.'$!`"0!````:0``H"@``#!`+>E8`)_E%-!-X@``C^!9_?_K`$"@X0``D.7@
M___K`,"@XSQ0G^4`$)3E.""?Y050C^`T,)_E`B"5YPP0C>4L$)_E`S"/X`P`
MG>4!$(_@`#"-Y03`C>47_?_K%-"-XC"`O>CD<`$`D&\!`'`!```,*P``0"@`
M````H.,>_R_A\$\MZ3PBG^4\,I_E2]Y-X@S03>("((_@`%"@X2P"G^4#,)+G
M&&"-X@%PH.$``(_@!!!&X@`PD^6T-(WE`#"@X]S]_^LO$*#C`$"@X04`H.&!
M_/_K``!0XQ````KP`9_E!1"@X0``C^`>___K!0"@X>`AG^70,9_E`B"/X`,P
MDN<`()/EM#2=Y0(@,^``,*#C:P``&DO>C>(,T(WB\(^]Z`<`H.'V_/_KK!&?
MY0$0C^"?_/_K`*!0XN?__PH`,-KEF)&?Y9B!G^68<9_E``!3XPF0C^`(@(_@
M!W"/X#T```H``%3C!```"@H0H.$$`*#A!_W_ZP``4.,M```*"@"@X?K\_^L`
M,*#A`2!`X@(@BN`"`%KA`+"@X0,PBC```*`S`1"*,@,``#H(``#J`P!1X0``
MP^4"```*`2!SY2\`4N/Y__\*"@"@X>C\_^L`L*#A!0"@X>7\_^L+`(#@`0"`
MX@$+4..\__\J_!"?Y;2PC>(!$(_@!S"@X0$KH.,B`(WI"P"@X0`0H.,`H(WE
M@/S_ZP80H.$+`*#A3?S_ZP``4.,#```:(#"=Y0\Z`^(""5/C%```"K00G^4`
M`*#C`1"/X%O\_^L`H%#BH___"@`PVN4``%/CP?__&@``5.,5```*`##4Y2X`
M4^,"```*`;"@XPF@H.'5___J`3#4Y0``4^/K__\*^/__Z@$0H.,+`*#AC/S_
MZP``4./E__\:4`"?Y0L0H.$``(_@KO[_ZPL`H.&3_/_KC?__Z@&PH.,(H*#A
MPO__ZC'\_^LL;P$`0`$``/@G``#,)P``R&X!`)0G``#4)@``T"8``&PG```P
M)@``A"8```PF```00"WI+Q"@XP!`H.']^__K``!0XP%`@!($`*#A$$"]Z'G\
M_^H00"WI`$!0X@D```H`,-3E``!3XP8```J-_/_K`0"`X@$+4.,&``"*!`"@
MX1!`O>CW_?_J$`"?Y1!`O>@``(_@:/S_Z@``H.,0@+WHS"0``'!`+>G$))_E
MQ#2?Y0(@C^#`5)_E`S"2Y[QDG^4(T$WB!5"/X``PD^4$,(WE`#"@XP9@C^`-
M0*#A!!"@X08`H.$A_?_K``!0XPX```J,-)_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I49)_E!F"/
MX`00H.$&`*#A"_W_ZP``4.,.```*-#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E
M``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J`&2?Y09@C^`$
M$*#A!@"@X?7\_^L``%#C#@``"MPSG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``
M4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZJQCG^4&8(_@!!"@
MX08`H.'?_/_K``!0XPX```J$,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I88Y_E!F"/X`00H.$&
M`*#AR?S_ZP``4.,.```*+#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!
M@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J!&.?Y09@C^`$$*#A!@"@
MX;/\_^L``%#C#@``"M0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G
M\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZK!BG^4&8(_@!!"@X08`H.&=
M_/_K``!0XPX```I\,I_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'_
M_PH$,(/B!""3Y0``4N,$((/D^___&NO__^I<8I_E!F"/X`00H.$&`*#AA_S_
MZP``4.,.```*)#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKK___J"&*?Y09@C^`$$*#A!@"@X7'\_^L`
M`%#C#@``"LPQG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P
M@^($()/E``!2XP0@@^3[__\:Z___ZK1AG^4&8(_@!!"@X08`H.%;_/_K``!0
MXPX```IT,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B
M!""3Y0``4N,$((/D^___&NO__^I@89_E!F"/X`00H.$&`*#A1?S_ZP``4.,.
M```*'#&?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J#`&?Y000H.$``(_@,/S_ZP`04.("```*^`"?
MY0``C^!W_?_K\`"?Y000H.$``(_@)_S_ZP`04.("```*W`"?Y0``C^!N_?_K
MU`"?Y000H.$``(_@'OS_ZP`04.(2```*P`"?Y0``C^!E_?_KN""?Y60PG^4"
M((_@`S"2YP`@D^4$,)WE`B`SX``PH.,0```:F!"?Y9@`G^4!$(_@``"/X`C0
MC>)P0+WH5?W_ZH0`G^4$$*#A``"/X`7\_^L`$%#BZ?__"G``G^4``(_@3/W_
MZ^7__^K4^O_K2&P!`$`!```T;`$`,"4``#@!``#@)```D"0``$0D``#T(P``
MK",``/0B```((P``O"(``'`B``"@(0``R"$``)PA``"X(0``A"```*@A``#<
M(```Z&<!`(0A``#T(```5"$``.0@```$X"WE>""?Y7@PG^4"((_@=`"?Y0S0
M3>(#,)+G#1"@X0``C^``,)/E!#"-Y0`PH./7^__K``!0XP4```H``-#E``!0
MXS``4!,!`*`#``"@$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@
M`#"@XP$``!H,T(WB!/"=Y)GZ_^L09P$`0`$``$P@``#`9@$`#P`MZ03@+>5$
M()_E1#"?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XRPPG^44((WB*`"?Y0,P
MC^``((WE``"3YQ`0G>6P`(#BV?K_Z_\`H.,^^O_K>&8!`$`!``!49@$`:`$`
M``(0H./P3RWI?$&?Y7SAG^4!V$WB'-!-X@1`C^`.X)3G`<B-X@`@H.,`,*#C
M`.">Y13@C.4`X*#C`!"-Y13`C.(`D*#AT/K_ZP%@4.(`$,'BP2^@X<$_)N`"
M,%/@<S#_Y@(P(^`",%/@`B#"X`-@5N`"@,'@``!8XSP``+H0L9_E$'&?Y1"A
MG^4+L(_@#%"-X@=PC^``$*#C!B"@X0@PH.$)`*#A`!"-Y;?Z_^L!`''C`0!P
M`S````H*(*#A!1"@X0D`H.%N^O_K`0!PXQ\```H'`%#C(```F@@`0.(`0)7@
M`P``.AP``.H!0$3B!0!4X1D``#H((*#C!Q"@X00`H.&5^O_K``!0X_;__QH%
M$$3@!@"1X,$?J."`P)_E;""?Y0S`C^`!.(WB`B"<YQ0P@^(`P)+E`""3Y0S`
M,N``(*#C$```&@'8C>(<T(WB\(^]Z$P`G^4``(_@C___ZP%H5N(`@,CB`0!X
MXP$(=@/(__\:``#@XP`0H.'F___J"P"@X87__^O+___J&?K_ZPQF`0!``0``
M8!\``!!G`0`(``$`!&4!`*0>```00"WI@OK_ZWOZ_^L``%#C``"0%1"`O>CP
M0"WI+"&?Y2QAG^4L,9_E`B"/X!303>(#,)+G!F"/X`!0H.$&`*#A"!"-X@`P
MD^4,,(WE`#"@XR?[_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C+P``&@40H.'(`)_E``"/X!30C>+P0+WH
M7_S_Z@40H.&W^?_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3Y0PPG>4"
M(#/@`#"@XQP``!H4T(WB\("]Z`4`H.%0^O_K`'"@X00`H.%-^O_K``"'X`(`
M@.)0^O_K8#"?Y6`0G^4%(*#A`$"-Y0,PC^`!$(_@`$"@X3GZ_^M(()_E+#"?
MY0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"K[Y_^M49`$`
M*!X``$`!```,9`$`R!T``,!C`0!L'```;!P``%1C`0#P3RWI1!:?Y43&G^5$
M)I_E`1"/X`(@D>=)WTWB#,"/X`PPC.(84(SB('"-XCC@C>(`()+E'"&-Y0`@
MH.,`D*#A!P"3Z`<`A^@/`+7H#P"NZ`,`E>@PP(SB+$"-X@,`CN@'`)SH!P"$
MZ.P%G^4<8(WB!A"@X0``C^#`^O_KW*6?Y0!04.(*H(_@`@``"@`PU>4``%/C
M#0$`&GO__^L`4%#B\0``"@4`H.$"^O_K@`"@X0$`@.(%^O_K`"#5Y0"`H.$`
M`%+C"0``"@A`H.&0M9_E"["/X`0`H.$+$*#A[/G_ZP$@]>4"0(3B``!2X_C_
M_QIP!9_E/%"-X@``C^`"``#J!`"5Y```4.,-```*!A"@X9KZ_^L`0%#B^/__
M"@`PU.4``%/C]?__"BG[_^L``%#C\O__"@0`H.'#^?_K`$!0XA,``!H`4*#C
M$CZ-X@4Q@^``01/E``!4XPP```H!L(7B"[&'X``PU.4``%/C!P``"@0`H.$6
M^__K``!0XP%0A>(W```:!$";Y```5./T__\:`$"@XP0`H.'&^?_K`%"@X0@`
MH.'#^?_K`%"%X`%;A>($4(7B!0"@X<3Y_^L`<*#AI#2?Y:04G^4#,(_@`#"-
MY9PTG^4$(*#A`S"/X`$0C^`$@(WEJOG_ZP<=H.,'`*#A>OG_ZP$`<..'```*
M!P"@X5`0C>(>^?_K`$!0XAD```I@))_E8!2?Y0(`FN<',*#A`""9Y0$0C^"P
M`(#B(/G_ZP!0H.-$))_E&#2?Y0(@C^`#,)+G`""3Y1PQG>4"(#/@`#"@X_P`
M`!H%`*#A2=^-XO"/O>@$`*#A=_G_ZP!`4.*T__\*QO__ZE@PG>4/.@/B`0E3
MX^'__QIL@)WE@_G_ZP``6.'=__\:6#"=Y8,[H.&C.Z#A!PU3X]C__QH%`*#A
MAOG_ZP!0H.'$`Y_E!A"@X0``C^`M^O_K`!!0XI0```H``)GE._S_ZP"`4.*0
M```*"`"@X7/Y_^L#`%#C`&"@X0P``)J,$Y_E!`!`X@``B.`!$(_@=/G_ZP``
M4.,%```:!`!6X[T```H&8(C@!3!6Y2\`4^.Y```*+_[_ZP!@4.($```:"`"@
MX080H.%.^?_K`(!0XG@``!H\$Y_E/`.?Y0$0C^```(_@5/O_ZR[Y_^L`P*#A
M*#.?Y2@3G^4#,(_@!#"-Y2`SG^4@DY_E((.?Y2!CG^4'(*#A!0"@X0,PC^`!
M$(_@`,"-Y0F0C^`(@(_@!F"/X#KY_^L-``#J`OG_ZP`PD.41`%/C#@``&A;Y
M_^L`P*#A`4"$X@DPH.$'(*#A"!"@X04`H.%0`(WI`,"-Y2OY_^L'':#C!0"@
MX?OX_^L!`'#C[/__"@<`H.&4^/_KI`*?Y040H.$``(_@)_O_ZP4`H.&B_O_K
MA?__ZN;X_^L`,)#E$0!3XW/__PH`()GE`%"@XQ0@C>7?^/_K`,"@X3`2G^4`
MP)SE`0":YUP2G^4',*#A%""=Y0$0C^``P(WEL`"`XI+X_^MQ___J!;"@X1(^
MC>(+,8/@]``3Y0``4.,@```*`8"+X@A1A.`&$*#ANOG_ZP`P4.((L*#A`@``
M"@`PT^4``%/C!```&@0`E>0``%#C$P``"@&`B.+R___JX?C_ZP!04.+H__\*
M]/[_ZG/^_^O8(9_E>#&?Y0(@C^`#,)+G`""3Y1PQG>4"(#/@`#"@XU0``!H%
M`*#A2=^-XO!/O>C0^/_J#0"@X^_X_^N@49_E4R"@XP"`H.$%4(_@Z/[_Z@"`
MF>5L___J[/W_ZP"@4>(`D*#A@O__N@H@4.(`,,KB`&"-Y0@`H.'H8(WBQOC_
MZP8@H.,&$*#A"`"@X8#X_^L&`%#C`@``"D@!G^4``(_@P?W_ZT`QG^7H()WE
M`P!2X6___QJT(-;A,#&?Y0,`4N%K__\:`!"@XS(@6>(`,,KB"`"@X0`0C>7P
M0(WBKOC_ZR@@H.,(`*#A!!"@X6CX_^LH`%#C`@``"O0`G^4``(_@J?W_ZP#`
MH./H()_EZ#"?Y>@0G^4"((_@!""-Y04`H.$'(*#A`$"-Y0,PC^`!$(_@&,'-
MY:'X_^MY___J!&"9Y0``5N-"__\*!@"@X:3X_^L#`%#C/O__FJ00G^4$`$#B
M``"&X`$0C^"F^/_K``!0XP:`H`$V___J(?C_Z_AB`0!H9`$`0`$``'@;``"$
M8@$`,!P``'@:``!,&P``+!L``)`9``!H`0``-!L``,Q@`0#L&@``M!H``'@9
M```$&0``+!L``%`:``#<%P``T!<``%0:``#X&@``Y!<``,08```L7@$`W!<`
M`%08````0T%#2$4``/07``"P&```;!4``-`7``"$%P``\$`MZ4PBG^5,,I_E
M`B"/X$@"G^4#,)+G#-!-X@``C^``,)/E!#"-Y0`PH.-M^/_K`#"@X0U@H.$`
M,)/E(`*?Y60@T^4&$*#A``"/X&4@P^43^?_K``!0XP(```H`,-#E,0!3XV,`
M``K:^__K]`&?Y?1!G^4``(_@6OC_ZP1`C^`$$*#A`S"@XP$@H.,`4*#A``"0
MY?;W_^L`0%#B"@``"@PPE.7$(9_E`!"3Y0``E>4"((_@T_?_ZPPPE.4`$)/E
M"#"1Y0$%$^-6```:H`&?Y:!!G^4``(_@0OC_ZP1`C^`$$*#A`S"@XP$@H.,`
M4*#A``"0Y=[W_^L`0%#B"0``"G0!G^4&$*#A``"/X.3X_^L`(%#B.P``"@PP
ME.4``)7E`!"3Y;?W_^M0`9_E4'&?Y0``C^`K^/_K2!&?Y0!0D.4!(*#C`$"@
MX0$0C^`%`*#AT_?_ZS`AG^4`$*#A`B"/X`4`H.&G]__K`""@XP`PE.48`9_E
M!A"@X0``C^!E(,/EQ_C_ZP=PC^```%#C"`"'Y1````H'':#CV??_ZP$P@.(1
M`%#C`0!3$R(``(K@()_EI#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ@`
M`!H,T(WB\("]Z`0`E^70_?_K``!0XP@`A^7I__\:I`"?Y0``C^"M]__K`3#0
MY0``4^.9__\*E___ZHPPG^4,()3E`S"/X`0PD^4``)+E`!"3Y:+Y_^N____J
M``"5Y;'W_^NE___J</?_ZV`@G^4`,*#A7`"?Y0(@C^`&`)+I``"/X``0D>65
M]__K(%P!`$`!``!`70$`&!4``.A<`0"L%@``?!8``(A<`0!8%@``%!0``"Q<
M`0"T7`$`\!4``/05``"8$P``>%H!`&@5```H7`$`]%L!`#`5``!P0"WI`$"@
MX33[_^LJ^__K`%"@X9/\_^L``%#C``!4$W"`O0@`,-3E``!3XW"`O0@@$)_E
M!""@XP4`H.$!$(_@&??_ZP``4.-P@+T8!`"@X7!`O>B?^/_J5!,``/!/+>E3
MWTWB#2"@X2@;G^4H.Y_E`1"/X`,PD><"P*#A`#"3Y40QC>4`,*#C'!"`XES@
M@.($,)'D,S^_Y@$`7N$$,*SE^O__&@%,C>("$*#A.#"1Y23@D>4,$)'E!,"R
MY0XP(^`!,"/@##`CX.,_H.$$`%+A0#""Y?/__QK`.I_E"""=Y0Q@D.4$$)WE
M$%"0Y0,@@N``4)#I`$"0Y09P@N`#$('@!B`NX`40@>`,(`+@!B`BX`R`G>7D
M'8'@`A"!X&PA+N!DD:#A`X"(X`0@`N`.L(C@#B`BX&R!*>`'((+@`8`(X!!P
MG>5L@2C@`W"'X`N`B.`4L)WEX2V"X&RAA^!A<2G@XHV(X`)P!^`#L(O@8B&@
MX0FPB^`)<"?@89$BX`B0">`*<(?@89$IX!B@G>7H?8?@"Y")X&BQ(N`#H(K@
M![`+X.>=B>!AH8K@9Q&@X0)P*^`*<(?@'*"=Y6BQ(>`#H(K@`B"*X""@G>4)
ML`O@`Z"*X.E]A^!HH8K@:($KX&FQ(>`"@(C@![`+X.>-B.!G(:#A`7`KX`IP
MA^`DH)WE:;$BX`.@BN`!H(K@*!"=Y0BP"^`#$('@:1&!X&F1*^#H?8?@"I")
MX&BA(N`'H`K@`J`JX`$0BN`LH)WEYYV)X`.@BN!G<:#A`J"*X#`@G>5HL2?@
M";`+X`,@@N!H(8+@:($KX.D=@>`*@(C@::$GX`&@"N`'H"K@`B"*X#2@G>7A
MC8C@`Z"*X&$1H.$'L(K@.'"=Y6FA(>`#<(?@"*`*X.@M@N!I<8?@::$JX&B1
M(>`"D`G@`9`IX`=PB>`\D)WE"Z"*X`.0B>#BK8K@`;")X&(AH.%`$)WE:)$B
MX`,0@>`*D`G@ZGV'X&@1@>!HD2G@:H$BX`>`".`"@"C@`8"(X$00G>4+D(G@
M`Q"!X.>=B>`"L('@9W&@X4@@G>5J$2?@`R""X`D0`>#IC8C@:B&"X&H1(>!I
MH2?@"*`*X`>@*N`"((K@3*"=Y0L0@>`#H(K@!W"*X%"@G>7H'8'@:(&@X0,P
MBN!IH2C@`:`*X&FA*N#A+8+@!Z"*X&%Q*.`"<`?@:3&#X`AP)^!8L)WE`W"'
MX!`XG^54D)WEXJV*X`.PB^!B(:#A`Y")X&&QB^!A$2+@"A`AX`B`B>#J?8?@
M`8"(X.>=B.!<@)WE`X"(X`*`B.!J(2+@!R`BX`(@B^#I'8+@8""=Y6=QH.$#
M((+@:B&"X&JA)^`)H"K@"H"(X&2@G>7AC8C@`Z"*X`>@BN!I<2?@`7`GX`=P
M@N!H()WE81&@X0,@@N!I(8+@:9$AX`B0*>`)D(K@;*"=Y>A]A^`#H(K@`:"*
MX&@1(>`'$"'@`1""X'`@G>7GG8G@`R""X&=QH.%H(8+@:($GX`F`*.`(@(K@
M=*"=Y>D=@>`#H(K@!Z"*X&EQ)^`!<"?@!W""X'@@G>7AC8C@`R""X&$1H.%I
M(8+@:9$AX`B0*>`)D(K@?*"=Y>A]A^`#H(K@`:"*X&@1(>`'$"'@`1""X(`@
MG>7GG8G@`R""X&=QH.%H(8+@:($GX`F`*.`(@(K@A*"=Y>D=@>`#H(K@!Z"*
MX&EQ)^!AL:#A`7`GX.&-B.`'<(+@:1$KX(@@G>4($"'@Z'V'X`$0BN`#((+@
M:*$KX&DA@N`'H"K@"J""X)`@G>7GG8'@C!"=Y6=QH.$#((+@:"&"X`,0@>!H
M@2?@"Q"!X`F`*.`(@('@E!"=Y>FMBN`#$('@!Q"!X&EQ)^`*<"?@!W""X)@@
MG>7JC8C@`R""X&JAH.%I(8+@:9$JX`B0*>`)$('@G)"=Y>A]A^`#D(G@"I")
MX&BA*N`'H"K@"B""X*"@G>7G'8'@`S"*X&=QH.%H,8/@:($GX`&`*.#A+8+@
M"(")X&&1)^`"D"G@XHV(X`DP@^#HG8/@I+"=Y;`UG^6HH)WE8B&@X0.PB^`'
ML(O@`Z"*X&%Q@N%AH8K@"'`'X&$1`N`!$(?A"Q"!X&BQ@N'I'8'@:7&@X0FP
M"^!HD0+@"9"+X:RPG>4*D(G@L*"=Y0.PB^`"L(O@`Z"*X&@AA^%HH8K@`2`"
MX&B!!^#AG8G@""""X6&!A^$+((+@"8`(X&&Q!^`+@(CAM+"=Y>DM@N`#L(O@
M!["+X+APG>5ID:#A"H"(X`-PA^!AH8GA`J`*X&%QA^!A$0G@XHV(X`$0BN%B
MH8GA"Q"!X`B@"N!BL0G@"Z"*X;RPG>7H'8'@`["+X`FPB^#`D)WE:(&@X0=P
MBN`#D(G@8J&(X0&@"N!BD8G@8B$(X.%]A^`"((KA8:&(X0L@@N`'H`K@8;$(
MX`N@BN'$L)WEYRV"X`.PB^`(L(O@R("=Y6=QH.$)D(K@`X"(X&&AA^$"H`K@
M88&(X&$1!^#BG8G@`1"*X6*AA^$+$('@":`*X&*Q!^`+H(KAS+"=Y>D=@>`#
ML(O@!["+X-!PG>5ID:#A"("*X`-PA^!BH8GA`:`*X&)QA^!B(0G@X8V(X`(@
MBN%AH8GA"R""X`B@"N!AL0G@"Z"*X=2PG>7H+8+@`["+X`FPB^#8D)WE:(&@
MX0=PBN`#D(G@8:&(X0*@"N!AD8G@81$(X.)]A^`!$(KA8J&(X0L0@>`'H`K@
M8K$(X`N@BN'<L)WE"9"*X."@G>7G'8'@`["+X&=QH.$(L(O@`Z"*X&*!A^%B
MH8K@`8`(X&(A!^#AG8G@`H"(X6$AA^$+@(C@"2`"X&&Q!^`+((+AY+"=Y0H@
M@N#HH)WEZ8V(X`.PB^!ID:#A!["+X`.@BN!A<8GA8:&*X`AP!^!A$0G@Z"V"
MX`%PA^%H$8GA"W"'X`(0`>!HL0G@"Q"!X0H0@>#LH)WEXGV'X`.@BN`)D(K@
M\*"=Y6(AH.$#,(K@:*&#X&@Q@N$',`/@:($"X`B`@^$)D(C@W#*?Y?2`G>7G
M'8'@9[&"X0.`B.`!L`O@`H"(X&<A`N`"((OA"B""X/B@G>7AG8G@`Z"*X&$1
MH.%GH8K@9W$AX`EP)^`'@(C@_'"=Y0"QG>4#<(?@Z2V"X`%PA^!I$2'@XHV(
MX`(0(>`#L(O@8B&@X0$0BN!IL8O@!*&=Y6F1(N`(D"G@"7"'X`.@BN`(D9WE
MZ!V!X`*@BN!H(2+@X7V'X`$@(N`#D(G@81&@X6B1B>!H@2'@!X`HX`B`BN`,
MH9WE`B"+X`.@BN#G+8+@`:"*X&<1(>`"$"'@`1")X!"1G>7BC8C@`Y")X&(A
MH.%GD8G@9W$BX`AP)^`'<(K@%*&=Y>@=@>`#H(K@`J"*X&@A(N`!("+@`B")
MX!B1G>7A?8?@`Y")X&$1H.%HD8G@:($AX`>`*.`(@(K@'*&=Y><M@N`#H(K@
M`:"*X&<1(>`"$"'@`1")X""1G>7BC8C@`Y")X&(AH.%GD8G@9W$BX`AP)^`'
M<(K@)*&=Y>@=@>`#H(K@`J"*X&@A(N`!("+@`B")X"B1G>7A?8?@`Y")X&$1
MH.%HD8G@:($AX`>`*.`(@(K@+*&=Y><M@N`#H(K@`:"*X&<1(>`"$"'@`1")
MX#"1G>7BC8C@`Y")X&(AH.%GD8G@9W$BX`AP)^`'<(K@-*&=Y>@=@>`#H(K@
M`J"*X&@A(N`!("+@`B")X#B1G>7A?8?@`Y")X&$1H.%HD8G@:($AX`>`*.#G
M+8+@"("*X.*-B.!H88;@#&"`Y3QAG>4#8(;@`6"&X&<1(>`"$"'@`1")X.@=
M@>!AX8[@"."`Y4#AG>5B(:#A`S".X&?A(N`"4(7@!#"#X`C@+N!H(2+@`2`B
MX&<Q@^`.X(;@X1V.X`(P@^#A/8/@`<",X`@0@.A$()_E+#"?Y0(@C^`04(#E
M`S"2YP`@D^5$,9WE`B`SX``PH.,!```:4]^-XO"/O>AN]/_K%%D!`$`!``"9
M>8):H>O9;MR\&X_6P6+*&$X!`'!`+>E@`*#CXO3_ZP`@H.,PP)_E,!"?Y3!0
MG^4P0)_E,."?Y0A0@.4,0(#E$."`Y0#`@.4$$(#E%""`Y1@@@.5<((#E<("]
MZ`$C16>)J\WO_MRZF'94,A#PX=+#\$<MZ0*0H.$`4*#A%#"0Y8(AH.$",)/@
M&""0Y10P@.5<`)#E`2""(JDN@N```%#C`4"@X1@@A>4<@(7B#@``"D!P8.('
M`%GA"7"@L0``B.`'(*#A-/3_ZUPPE>4#,(?@0`!3XUPPA>7PA[T8!0"@X0>0
M2>`'0(3@\_S_ZS\`6>,=``#:0)!)XBECH.$!<(;B!W.$X`@PH.%`X(3B`,"4
MY00`E.4($)3E#""4Y1!`A.(.`%3A`,"#Y00`@^4($(/E#""#Y1`P@^+S__\:
M!0"@X=W\_^L'`%3A[?__&@9M9N`&DXG@"2"@X0<0H.$(`*#A#?3_ZUR0A>7P
MA[WH!'"@X??__^I_P.#C\$$MZ10PD>488)'E,W^_YJ,QH.$_,`/B`2"#XAR`
M@>(X`%+C`%"@X0%`H.$V;[_F`\#(YP(`B.`[``#:`!"@XT`@8N(4]/_K!`"@
MX;S\_^L(`*#A.""@XP`0H.,.]/_K!`"@X?1EQ.&U_/_K`S#4Y00`H.$`,,7E
MLC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4X04PQ>4$
M,)3E(S2@X08PQ>4$,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E(S2@X0HP
MQ>4(,)3E"S#%Y0\PU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,,)3E#S#%
MY1,PU.40,,7ELC'4X1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y?!!O>BB\__J
M`!"@XS@@8N+8\__KR/__ZA!`+>E8,)_E6$"?Y0,PC^`D(-/E!$"/X```4N,0
M@+T8`1"@XT`@G^4D$,/E`C"4YP``4^,"```*,#"?Y0,`G^=U\__K*#"?Y0,P
ME.<``%/C$("]"!P`G^400+WH``"/X.+S_^H(30$`'$L!`!P!``!L3`$`5`$`
M`&1%```\$)_E/#"?Y0$0C^``(-'E`S"/X```4N,>_R\1`0"@XR0@G^4``,'E
M`C"3YP``4^,>_R\!%`"?Y000@>(``(_@U//_ZI!,`0"D2@$`6`$```A%``#P
M0"WI3,*?Y2303>)(,I_E%`"-Y1`0C>4,((WE#,"/X`,PG.<0$(WB#""-XA0`
MC>(H0I_E`#"3Y1PPC>4`,*#CH?/_ZQ@BG^4$0(_@%#*?Y0(@E.<#`)3G`A"@
MX:;S_^L$,I_E`S"4YP!0T^4``%7C40``"O0!G^4``(_@YO/_ZP`@D.448)WE
M1C/2Y000AN(#,(/C!P%QXP-@AN)&,\+E8@``B@$!H.%[\__K`#"@X1`0G>6X
M<9_E``"1Y;3AG^4'<(_@@0"#Z*S!G^4.X(_@J"&?Y00PCN4,`)3G`B"/X!10
MG>4,((/E`""0Y0$`5>,(((/E4@``V@0`0>(,P(/B!0&`X`3@L>4!`%#A!."L
MY?O__QH#4(7B`,"@XV!!G^5@$9_E!$"/X`P`E.4&(*#A`,"-Y0$0C^`%P8/G
M@_/_ZP``4.,I```*/%&?Y1A@C>(%4(_@#`"5Y3'S_^L`0*#A*`&?Y080H.$`
M`(_@6?3_ZP``4.,@```*%#&?Y0,PC^`,`)/E%_/_ZU[S_^L$(9_EQ#"?Y0(@
MC^`#,)+G`""3Y1PPG>4"(#/@`#"@XR@``!H$`*#A)-"-XO"`O>@A\__KU""?
MY0``4.,"((_@#`""Y1T```KW\O_KP`"?Y0``C^"-\__K`#"0Y>95P^6@___J
M#`"4Y7#S_^O2___J"`"5Y0``4.,!```*L_O_Z]G__^J,`)_E!A"@X0``C^`M
M]/_K``!0XP@`A>72__\*]?__ZG`PG^5P`)_E`Q"4YP``C^`G\__K!%"@X[+_
M_^H!`*#CM/+_Z_7R_^M$2@$`0`$``!A*`0!0`0``8`$``"P!```82P$`-`4`
M`*!+`0!,`0``'`4``$A+`0!DV?__'$L!`#P"``#P2@$`S$@!`*1*`0"T20$`
M+`$``$@!``#X`@``<'-?<W1R:6YG<R!M:7-S:6YG"@`O=&UP+P```"X```!0
M05)?5$U01$E2``!414U01$E2`%1-4`!54T52`````%5315).04U%`````"5S
M+R5S````+W!R;V,O8W5R<')O8R]E>&4```!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````4$%27U1%35``````
M4$%27U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL960`
M````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```
M```E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;```
M```N<&%R`````'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M
M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P````
M4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3D```!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M`"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T
M7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@
M/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A
M8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`]
M(")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H
M*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I
M>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M
M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E
M96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@
M*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD
M<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF
M:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC
M:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO
M9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I
M;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=
M*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N
M86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M
M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R
M;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A
M;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA
M9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I
M+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D
M8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S
M*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S
M*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B
M=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").
M(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES
M("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@
M/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L
M(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S
M="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY
M("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F
M=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L
M97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM
M;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M
M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F
M:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-
M04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I
M;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A
M<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;
M(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:
M25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@
M)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A
M9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS
M92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E
M<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?
M:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O
M0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\
M+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@
M("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L
M("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C
M*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y
M(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO
M72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN
M97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I
M(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT
M9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL
M92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L
M("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T
M:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO
M=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D
M;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B
M7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P
M+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C
M:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE
M7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B
M*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD[
M"B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O
M9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q
M6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT
M<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D
M97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C
M86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`]
M(")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P
M<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=
M.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^
M/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L
M("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*
M<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<
M,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F
M:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D
M(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M
M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*
M=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL
M;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA
M;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S
M>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?
M)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB
M4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`````
M0T%#2$4```$;`SL``0``'P```-2,__\8`0``,(W__S0!``"HC?__5`$``%"/
M__^D`0``+)#__\@!``"DD?__]`$``$B2__\8`@``7)/__TP"``"`E/__?`(`
M`+R6__^L`@``&)?__]`"``"0E___\`(``)B7__\$`P``$)K__SP#```TFO__
M7`,``(2:__^$`P``O)___[0#``!0H/__U`,``+2@___X`P``7*+__S`$``!T
MHO__2`0``-"C__^`!```K*K__\@$``!4K?__\`0``+"M__\\!0``"+G__W`%
M``!DN?__C`4``&BZ__^P!0``J+O__X0!```DO/__<`$``'B\__\4!0``$```
M```````!>E(``GP.`1L,#0`8````&````+2+__]<`````%(.$(0$A0.&`HX!
M'````#0```#TB___>`````!"#AB$!H4%A@2'`X@"C@$8````5````$R,__^H
M`0```$(."(<"C@%(#A``$````'````"LNO__5``````````<````A````!RZ
M__]\`````$(."(0"C@%LSL0.`````"````"D````I(W__]P`````1`X@A`B%
M!X8&AP6(!(D#B@*.`2@```#(````7([__W@!````0@X<A`>%!H8%AP2(`XD"
MC@%*#L`!9`H.'$(+(````/0```"HC___I`````!"#@B$`HX!2`ZH`7(*#@A"
M"P``,````!@!```HD/__%`$```!"#@B$`HX!1@Z("$(.D`@"5`H."$(+6@H.
M"$+.Q`X`0@L``"P```!,`0``")'__R0!````0@X4A`6%!(8#AP*.`4H.E`A$
M#J`(`FP*#A1""P```"P```!\`0``_)'__SP"````0@X@A`B%!X8&AP6(!(D#
MB@*.`4P.*`*8"@X@0@L``"````"L`0``")3__UP`````0@X0A`2%`X8"C@%>
MSL;%Q`X``!P```#0`0``0)3__W@`````0@X,A`.%`HX!1`X@:@X,$````/`!
M``"8E/__"``````````T````!`(``(R4__]X`@```$(.)(0)A0B&!X<&B`6)
M!(H#BP*.`48.U`E"#N`)`D0*#B1""P```!P````\`@``S);__R0`````0@X(
MA`*.`4[.Q`X`````)````%P"``#0EO__4`````!"#@B$`HX!5@K.Q`X`0@M$
M"L[$#@!$"RP```"$`@``^);__S@%````0@X0A`2%`X8"C@%.#A@#/@(*#A!"
MSL;%Q`X`0@L``!P```"T`@```)S__Y0`````0@X$C@%*#A!R"@X$0@L`(```
M`-0"``!TG/__9`````!"#A"`!($#@@*#`4(.%(X%2@X@-````/@"``"TG/__
MJ`$```!$#B2$"84(A@>'!H@%B02*`XL"C@%&#J2`!$(.P(`$`IH*#B1""P`4
M````,`,``"2>__\8`````$(."(0"C@$T````2`,``"2>__]<`0```$(.%(0%
MA02&`X<"C@%*#BAV"@X40L['QL7$#@!""UP*#A1""P```$0```"``P``2)__
M_]P&````0@XDA`F%"(8'AP:(!8D$B@.+`HX!3`[(`@,B`0H.)$(+`TX!"@XD
M0L[+RLG(Q\;%Q`X`0@L``"0```#(`P``W*7__Z@"````0@X4A`6%!(8#AP*.
M`4P.(`+<"@X40@L@````\`,``%RH__]<`````$(.$(0$A0.&`HX!:,[&Q<0.
M```D````%`0``%RW__^P`@```$(.%(0%A02&`X<"C@%$#C@"U@H.%$(+,```
M`#P$``!LJ/__6`L```!"#B2$"84(A@>'!H@%B02*`XL"C@%"#O`"`Y8%"@XD
M0@L``!@```!P!```D+/__UP`````0@X0A`2%`X8"C@$@````C`0``-"S__\$
M`0```$(.((0(A0>&!H<%B`2)`XH"C@$L````L`0``+"T__]``0```$0.&(0&
MA06&!(<#B`*.`0*2"L[(Q\;%Q`X`0@L`````````*$8``*Q%`````````0``
M``$````!````RP(```$```#5`@```0```.H"```!````"0,```\```"B!```
M&0```.B/`0`;````!````!H```#LCP$`'`````0````$````>`$```4```!T
M"P``!@```+0$```*````ZP0```L````0````%0`````````#````Y)`!``(`
M```8`@``%````!$````7````>!$``!$```!@$```$@```!@!```3````"```
M`/O__V\````(^O__;Q<`````````````````````````````````````````
M````````````````](\!````````````D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,`
M`)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``
MD!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``)`3``"0$P``D!,``/"/`0````````````````#HCP$`````
M`````````````),!````````````[(\!``````"<D@$`````````````````
M](\!``````#$D@$``````%B2`0"P-```P)(!`%R2`0`*4$%2+G!M"@````!`
M20``2$D```````!,20``4$D``%A)``#,20``8$D```````!D20``;$D`````
M``"`3```1T-#.B`H3F5T0E-$(&YB,R`R,#(S,3`P."D@,3`N-2XP`$=#0SH@
M*&YB,R`R,#(S,3`P."D@,3`N-2XP`"1.971"4T0Z(&-R=#`N4RQV(#$N-"`R
M,#$X+S$Q+S(V(#$W.C,W.C0T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=#`M
M8V]M;6]N+F,L=B`Q+C(W(#(P,C(O,#8O,C$@,#8Z-3(Z,3<@<VMR;&P@17AP
M("0`)$YE=$)31#H@8W)T:2Y3+'8@,2XQ(#(P,3(O,#@O,3,@,#(Z-#DZ,#0@
M;6%T="!%>'`@)``D3F5T0E-$.B!C<G1B96=I;BYC+'8@,2XQ-R`R,#$X+S$R
M+S(X(#$X.C$W.C$Q(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3
M+'8@,2XR(#(P,3,O,3(O,C`@,34Z,S4Z-#@@:F]E<F<@17AP("0`\<\"````
M``````````````@````(````"`````@````;`````0``````````*BHJ($YO
M($QA8F5L(%!R;W9I9&5D("HJ*@``\<\"``````````````````@````(````
M"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D("HJ
M*@!!+@```&%E86)I``$D````!39+6@`&!P@!"0$*`A($%`$5`1<#&`$:`AP!
M(@%$`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92YN971B<V0N:61E;G0`+FYO
M=&4N;F5T8G-D+G!A>``N;F]T92YN971B<V0N;6%R8V@`+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YT97AT`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+FIC<@`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?
M8W1F`"Y!4DTN871T<FEB=71E<P`N;F]I;FET````````````````````````
M````````````````````````````````"P````$````"````%`$``!0!```7
M```````````````!`````````!,````'`````@```"P!```L`0``&```````
M````````!``````````F````!P````(```!$`0``1`$``!0`````````````
M``0`````````-P````<````"````6`$``%@!```@```````````````$````
M`````$H````%`````@```'@!``!X`0``/`,```8`````````!`````0```!0
M````"P````(```"T!```M`0``,`&```'`````P````0````0````6`````,`
M```"````=`L``'0+``#K!``````````````!`````````&`````)`````@``
M`&`0``!@$```&`$```8`````````!`````@```!I````"0```$(```!X$0``
M>!$``!@"```&````$P````0````(````;0````$````&````D!,``)`3```X
M`P`````````````$````!````'(````!````!@```,@6``#(%@``9#(`````
M````````!`````````!X`````0````(````L20``+$D``-=`````````````
M``0`````````@`````$````"````!(H```2*```$`0`````````````$````
M`````(X````!`````@````B+```(BP``X`0`````````````!`````````"8
M````#@````,```#HCP$`Z(\```0```````````````0````$````I`````\`
M```#````[(\!`.R/```$```````````````$````!````+`````!`````P``
M`/"/`0#PCP``!```````````````!`````````"U````!@````,```#TCP$`
M](\``/`````'``````````0````(````O@````$````#````Y)`!`.20``!T
M`0`````````````$````!````,,````!`````P```%B2`0!8D@``2```````
M````````!`````````#)````"`````,```#`D@$`H)(``$0`````````````
M`$``````````S@````$````P`````````*"2```]```````````````!````
M`0```!\````!````,`````````#=D@``'P$``````````````0````$```#7
M`````0``````````````_),``(\```````````````0`````````X0````,`
M`'```````````(N4```O```````````````!`````````/$````!`````0``
M``23`0"ZE````````````````````0`````````!`````P``````````````
8NI0``/D```````````````$`````````
